@@ -8,13 +8,13 @@
 # Trac extension point imports
 from trac.core import *
 from trac.web.api import IRequestFilter
-from trac.web.chrome import add_stylesheet, ITemplateStreamFilter
 from trac.util.translation import _
 from trac.config import BoolOption
 from trac.resource import ResourceNotFound
 from trac.ticket.model import Component as TicketComponent  # Make sure not to confuse with Component for plugins
 from trac.ticket.model import Milestone, Version
 from trac.ticket.api import IMilestoneChangeListener
+from trac.web.chrome import add_script, add_script_data, add_stylesheet, ITemplateStreamFilter
 from genshi.builder import tag
 from genshi.filters.transform import Transformer, InjectorTransformation
 from genshi.template.markup import MarkupTemplate
@@ -117,6 +117,15 @@ def get_milestone_from_trac(env, name):
     except ResourceNotFound:
         return None
 
+projects_tmpl = """
+<div xmlns:py="http://genshi.edgewall.org/" id="smp-ms-sel-div" py:if="all_projects">
+$proj
+<select id="smp-project-sel">
+    <option value="" selected="'' == sel_prj or None}">$all_label</option>
+    <option py:for="prj in all_projects" value="$prj" selected="${prj == sel_prj or None}">$prj</option>
+</select>
+</div>
+"""
 
 class SmpFilterDefaultMilestonePanels(Component):
     """Modify default Trac admin panels for milestones to include project selection.
@@ -191,6 +200,7 @@ class SmpFilterDefaultMilestonePanels(Component):
         if filename == "admin_milestones.html":
             # ITemplateProvider is implemented in another component
             add_stylesheet(req, "simplemultiproject/css/simplemultiproject.css")
+            add_script(req, "simplemultiproject/js/filter_milestone_table.js")
             if self.single_project:
                 input_type = 'radio'
             else:
@@ -214,10 +224,16 @@ class SmpFilterDefaultMilestonePanels(Component):
                             # missing from the SMP milestone table
                             all_ms_proj[ms] = [""]
 
+                add_script_data(req, {'smp_proj_ms': all_ms_proj})
                 # Add project column to main milestone table
                 stream = stream | Transformer('//table[@id="millist"]//th[2]').after(tag.th(_("Project")))
                 stream = stream | Transformer('//table[@id="millist"]//tr').apply(InsertProjectTd("", all_ms_proj))
-
+                # Add select control with projects for hiding milestones
+                sel = MarkupTemplate(projects_tmpl)
+                all_proj = self.env.config.getlist('ticket-custom', 'project.options', sep='|')
+                stream = stream | Transformer('//table[@id="millist"]').\
+                   before(sel.generate(proj=_("Project"), all_projects=all_proj,
+                                       sel_prj="", all_label=_("All")))
                 # The 'add milestone' part of the page
                 if not self.allow_no_project:
                     stream = stream | Transformer('//head').append(create_script_tag(input_type=input_type))\
@@ -331,6 +347,7 @@ class SmpFilterDefaultVersionPanels(Component):
         if filename == "admin_versions.html":
             # ITemplateProvider is implemented in another component
             add_stylesheet(req, "simplemultiproject/css/simplemultiproject.css")
+            add_script(req, "simplemultiproject/js/filter_version_table.js")
             if self.single_project:
                 input_type = 'radio'
             else:
@@ -347,11 +364,17 @@ class SmpFilterDefaultVersionPanels(Component):
                     except KeyError:
                         # A version without a project
                         all_ver_proj[ver] = [all_proj[p_id]]
-
+                add_script_data(req, {'smp_proj_ver': all_ver_proj})
                 # Add project column to main version table
                 stream = stream | Transformer('//table[@id="verlist"]//th[2]').after(tag.th(_("Project")))
                 stream = stream | Transformer('//table[@id="verlist"]//tr').apply(InsertProjectTd("", all_ver_proj))
 
+                sel = MarkupTemplate(projects_tmpl)
+                all_proj = self.env.config.getlist('ticket-custom', 'project.options', sep='|')
+                stream = stream | Transformer('//table[@id="verlist"]'). \
+                    before(sel.generate(proj=_("Project"), all_projects=all_proj,
+                                        sel_prj="", all_label=_("All")))
+
                 # The 'add version' part of the page
                 if not self.allow_no_project:
                     stream = stream | Transformer('//head').append(create_script_tag(input_type=input_type))\
@@ -525,3 +548,54 @@ class SmpFilterDefaultComponentPanels(Component):
                 filter_form = Transformer('//form[@id="modcomp"]//div[@class="field"][1]')
                 stream = stream | filter_form.after(create_projects_table(self, self._SmpModel, req))
         return stream
+
+class SmpAddExtendedVersionColumn(Component):
+    """Add version column to milestone table when using ExtendedVersion plugin."""
+
+    implements(IRequestFilter)
+
+    def __init__(self):
+        self.extended_version = self._get_ext_version(self.env.get_read_db()) != 0
+        if self.extended_version:
+            try:
+                from extendedversion.milestone import MilestoneVersion
+                self.extended_version = self.env.enabled[MilestoneVersion]
+            except ImportError:
+                self.extended_version = False
+
+    def _get_ext_version(self, db):
+        cursor = db.cursor()
+        try:
+            cursor.execute(
+                    """SELECT value FROM system
+                       WHERE name='extended_version_plugin'""")
+            row = cursor.fetchone()
+            if row:
+                return int(row[0])
+            else:
+                return 0
+        except:
+            return 0
+
+    # IRequestFilter methods
+
+    def pre_process_request(self, req, handler):
+        return handler
+
+    def post_process_request(self, req, template, data, content_type):
+        if self.extended_version and template == 'admin_milestones.html':
+            if data and data['view'] == 'list':
+                add_script_data(req, {'ms_ext_version': self.get_version_for_milestone()})
+                add_script(req, "simplemultiproject/js/add_version_column.js")
+
+        return template, data, content_type
+
+    def get_version_for_milestone(self):
+        data = {}
+        if self.extended_version:
+            db = self.env.get_read_db()
+            cursor = db.cursor()
+            cursor.execute('SELECT * FROM milestone_version')
+            for row in cursor:
+                data.update({row[0]: row[1]})
+        return data
