@@ -49,7 +49,7 @@ class SmpRoadmapGroup(Component):
 
     def post_process_request(self, req, template, data, content_type):
         path_elms = req.path_info.split('/')
-        if data and path_elms[1] == 'roadmap':
+        if data and len(path_elms) > 1 and path_elms[1] == 'roadmap':
             # ITemplateProvider is implemented in another component
             add_stylesheet(req, "simplemultiproject/css/simplemultiproject.css")
 
@@ -110,7 +110,7 @@ class SmpRoadmapGroup(Component):
         if filename == 'roadmap.html':
             # Change label to include versions
             filter_ = Transformer('//label[@for="showcompleted"]')
-            stream = stream | filter_.replace(HTML('<label for="showcompleted">Show completed milestones and '
+            stream = stream | filter_.replace(HTML(u'<label for="showcompleted">Show completed milestones and '
                                                    'versions</label>'))
             # Add additional checkboxes to preferences
             data['smp_render'] = 'prefs'  # specify which part of template to render
@@ -120,7 +120,7 @@ class SmpRoadmapGroup(Component):
             if group_proj:
                 chked = 'checked="1"'
             filter_ = Transformer('//form[@id="prefs"]')
-            stream = stream | filter_.prepend(HTML('<div>'
+            stream = stream | filter_.prepend(HTML(u'<div>'
                                                    '<input type="hidden" name="smp_update" value="group" />'
                                                    '<input type="checkbox" id="groupbyproject" name="smp_group" '
                                                    'value="1" %s />'
@@ -158,7 +158,7 @@ class SmpRoadmapModule(Component):
         """Call extensions adding data or filtering data in the appropriate order."""
         if data:
             path_elms = req.path_info.split('/')
-            if path_elms[1] == 'roadmap':
+            if len(path_elms) > 1 and path_elms[1] == 'roadmap':
                 for provider in self.data_provider:
                     data = provider.add_data(req, data)
 
@@ -245,7 +245,7 @@ class SmpRoadmapProjectFilter(Component):
 
     def filter_stream(self, req, method, filename, stream, data):
         path_elms = req.path_info.split('/')
-        if path_elms[1] == 'roadmap':
+        if len(path_elms) > 1 and path_elms[1] == 'roadmap':
             # Add project selection to the roadmap preferences
             xformer = Transformer('//form[@id="prefs"]')
             stream = stream | xformer.prepend(create_proj_table(self, self._SmpModel, req))
